@@ -60,8 +60,9 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
 
     Returns
     -------
-    tuple[str, pandas.DataFrame]
-        (response, response_data_frame) - Returns the response status and the dataframe containing the parsed response text.
+    tuple[pandas.DataFrame, pandas.DataFrame]
+        (response_df, errors_df) - Returns the response dataframe and the dataframe containing the parsed errors text
+        (if no errors, then empty dataframe).
 
     """
 
@@ -165,15 +166,6 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
                       'UnitOfMeasureAbbrev', 'DeviceName', 'DisplayName', 'EquipmentType', 'EquipmentLabel',
                       'DeviceTags', 'SensorTags', 'OntologyTags', 'Metadata', 'DiscoveryProperties']
 
-    # if set(data_frame.columns.tolist()).issubset(final_req_cols):
-    #     discovery_payload = data_frame.groupby(
-    #         by=['ApiProjectId', 'InstallationId', 'NetworkDeviceId', 'DriverClassName', 'UserId', 'BatchNo']).apply(
-    #         lambda x: x[['DriverUniqueId', 'CurrentValue', 'DriverDeviceType', 'ObjectPropertyTemplateName',
-    #                      'UnitOfMeasureAbbrev', 'DeviceName', 'DisplayName', 'EquipmentType', 'EquipmentLabel',
-    #                      'DeviceTags', 'SensorTags', 'OntologyTags', 'Metadata', 'DiscoveryProperties']].to_dict(
-    #             orient='records')).reset_index().rename(columns={0: 'Sensors'}).to_json(orient='records')
-    #     discovery_payload = discovery_payload[1:-1]  # remove outer [] from json
-
     if set(data_frame.columns.tolist()).issubset(final_req_cols):
         batch_size = 50
         chunk_list = []
@@ -200,11 +192,6 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
             response = requests.post(url=url, headers=headers, data=discovery_payload)
 
             response_status = '{} {}'.format(response.status_code, response.reason)
-            # if response.status_code != 200:
-            #     logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
-            #                  response.reason)
-            #     return response_status, pandas.DataFrame()
-
             if response.status_code != 200 and len(response.text) > 0:
                 logger.error(f"API Call was not successful. Response Status: {response.status_code}. "
                              f"Reason: {response.reason}. Error Text: {response.text}")
@@ -235,42 +222,9 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
 
         if 0 < len(payload_error_list) <= grouped_df.ngroups:
             payload_error_df = pandas.DataFrame(payload_error_list)
-            logger.error(f"")
+            logger.error(f"Errors on upsert of discovered records. ")
             return upsert_response_df, payload_error_df
 
-        # for name, group in grouped_df:
-        #     discovery_payload = data_frame.groupby(
-        #         by=['ApiProjectId', 'InstallationId', 'NetworkDeviceId', 'DriverClassName', 'UserId', 'BatchNo']).apply(
-        #         lambda x: x[['DriverUniqueId', 'CurrentValue', 'DriverDeviceType', 'ObjectPropertyTemplateName',
-        #                      'UnitOfMeasureAbbrev', 'DeviceName', 'DisplayName', 'EquipmentType', 'EquipmentLabel',
-        #                      'DeviceTags', 'SensorTags', 'OntologyTags', 'Metadata', 'DiscoveryProperties']].to_dict(
-        #             orient='records')).reset_index().rename(columns={0: 'Sensors'}).to_json(orient='records')
-        #     discovery_payload = discovery_payload[1:-1]  # remove outer [] from json
-    #
-    #         payload = discovery_payload
-    #
-    #         logger.info(f"Upserting discovery record group {name}")
-    #         response = requests.post(url=url, headers=headers, json=discovery_payload )
-
-    # url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/integrations/driver-discovery"
-    # headers = api_inputs.api_headers.integration
-    # payload=discovery_payload
-
-    # response = requests.post(url=url, headers=headers, json=discovery_payload )
-    # logger.info("Sending request: POST %s", url)
-    #
-    # response_data_frame = pandas.read_json(response.text)
-    # response_status = '{} {}'.format(response.status_code, response.reason)
-    # if response.status_code != 200:
-    #     logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
-    #                  response.reason)
-    #     return response_status, pandas.DataFrame()
-    # elif len(response.text) == 0:
-    #     logger.error('No data returned for this API call. %s', response.request.url)
-    #     return response_status, pandas.DataFrame()
-    #
-    # return response_status, response_data_frame
-    # return data_frame, discovery_payload
     return upsert_response_df, pandas.DataFrame()
 
 
@@ -1098,8 +1052,7 @@ def append_data(data_frame, api_inputs: ApiInputs, table_name: str):
     return response_status, response_df
 
 
-# TODO : Kate please review this new helper method for upserting row count
-def upsert_file_row_count(api_inputs: ApiInputs, row_count: int = None):
+def upsert_file_row_count(api_inputs: ApiInputs, row_count: int):
     """Updates data feed file status row count.
 
     Parameters
@@ -1109,11 +1062,10 @@ def upsert_file_row_count(api_inputs: ApiInputs, row_count: int = None):
     row_count : number
         Number of rows
 
-
     Returns
     -------
-    None.
-
+    str
+        Response status as a string.
     """
 
     if row_count is None:
