@@ -6,9 +6,11 @@
 """Module defining the Task abstract base class which is inherited by the following specific task types:
 
 - IntegrationTask
+- DiscoverableIntegrationTask
 - AnalyticsTask
 - LogicModuleTask
 - QueueTask
+- EventWorkOrderTask
 
 Also includes the Automation class which contains helper functions.
 
@@ -22,6 +24,19 @@ Examples include:
     - Pulling readings or other types of data from REST APIs
     - Protocol Translators which ingest data sent to the platform via email, ftp or direct upload within platform.
 
+---------------------------
+DiscoverableIntegrationTask
+---------------------------
+Base class used to create integrations between the Switch Automation platform and 3rd party APIs.
+
+Similar to the IntegrationTask, but includes a secondary method `run_discovery()` which triggers discovery of available
+points on the 3rd party API and upserts these records to the Switch Platform backend so that the records are available
+in Build - Discovery & Selection UI.
+
+Examples include:
+    - Pulling readings or other types of data from REST APIs
+
+
 -------------
 AnalyticsTask
 -------------
@@ -52,6 +67,13 @@ functions for retrieving details of existing tasks on the Switch Automation plat
 
 """
 
-from .pipeline import IntegrationTask, QueueTask, LogicModuleTask, AnalyticsTask, Automation, logger
+from .pipeline import (IntegrationTask, QueueTask, LogicModuleTask, AnalyticsTask, DiscoverableIntegrationTask,
+                       logger)  # , EventWorkOrderTask
+from .automation import Automation
+from .definitions import (IntegrationDeviceConfigPropertyDefinition, IntegrationDeviceDefinition,
+                          DiscoveryIntegrationInput, BaseProperty, AnalyticsSettings)  # , EventWorkOrderFieldDefinition
 
-__all__ = ['IntegrationTask', 'QueueTask', 'LogicModuleTask', 'AnalyticsTask', 'Automation', 'logger']
+__all__ = ['IntegrationTask', 'QueueTask', 'LogicModuleTask', 'AnalyticsTask', 'DiscoverableIntegrationTask',
+           'Automation', 'logger', 'IntegrationDeviceConfigPropertyDefinition',
+           'IntegrationDeviceDefinition', 'DiscoveryIntegrationInput', 'BaseProperty',
+           'AnalyticsSettings']  # 'EventWorkOrderTask', 'EventWorkOrderFieldDefinition',
