@@ -370,7 +370,7 @@ class Automation:
     @staticmethod
     def deploy_as_email_data_feed(task, api_inputs: ApiInputs, expected_delivery: EXPECTED_DELIVERY,
                                   email_subject_regex: str, email_address_domain='switchautomation.com',
-                                  queue_name: QUEUE_NAME = 'task',
+                                  queue_name: QUEUE_NAME = 'task', data_feed_name: str = None,
                                   data_feed_id: uuid.UUID = None):
         """Deploy task as an email data feed.
 
@@ -393,6 +393,9 @@ class Automation:
             The email domain, without the @ symbol, of the sender (Default value = 'SwitchAutomation.com').
         queue_name : QUEUE_NAME, optional
             The name of queue (Default value = 'task').
+        data_feed_name : str, Optional
+            The name of the data feed (to be displayed in Task Insights UI). If not provided, will default to the
+            task name.
         data_feed_id : uuid.UUID, Optional
             The DataFeedId to update if existing, else will create a new record with the given value.
 
@@ -407,8 +410,12 @@ class Automation:
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        if data_feed_id is None:
+        if data_feed_id is None and data_feed_name is None:
             data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+            data_feed_name = task.__class__.__qualname__
+        elif data_feed_id is not None and data_feed_name is None:
+            data_feed_id = data_feed_id
+            data_feed_name = data_feed_name
 
         headers = api_inputs.api_headers.default
 
@@ -440,7 +447,7 @@ class Automation:
         payload = {
             "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
-            "name": 'Feed Settings for ' + type(task).__name__,
+            "name": data_feed_name,
             "feedType": ",".join(task.mapping_entities),
             "expectedDelivery": expected_delivery,
             "sourceType": "email",
@@ -474,7 +481,7 @@ class Automation:
     @staticmethod
     def deploy_as_ftp_data_feed(task, api_inputs: ApiInputs, ftp_user_name, ftp_password,
                                 expected_delivery: EXPECTED_DELIVERY, queue_name: QUEUE_NAME = 'task',
-                                data_feed_id: uuid.UUID = None):
+                                data_feed_name: str = None, data_feed_id: uuid.UUID = None):
         """Deploy the custom driver as an FTP data feed
 
         Deploys the custom driver to receive data via an FTP data feed. Sets the `ftp_user_name` & `ftp_password` and
@@ -495,6 +502,9 @@ class Automation:
             The expected delivery frequency of the data.
         queue_name : QUEUE_NAME, default = 'task'
             The queue name (Default value = 'task').
+        data_feed_name : str, Optional
+            The name of the data feed (to be displayed in Task Insights UI). If not provided, will default to the
+            task name.
         data_feed_id : uuid.UUID, Optional
             The DataFeedId to update if existing, else will create a new record with the given value.
 
@@ -511,6 +521,8 @@ class Automation:
 
         if data_feed_id is None:
             data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+        if data_feed_name is None:
+            data_feed_name = task.__class__.__qualname__
 
         headers = api_inputs.api_headers.default
 
@@ -531,7 +543,7 @@ class Automation:
         payload = {
             "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
-            "name": 'Feed Settings for ' + type(task).__name__,
+            "name": data_feed_name,
             "feedType": ",".join(task.mapping_entities),
             "expectedDelivery": expected_delivery,
             "sourceType": "ftp",
@@ -564,7 +576,7 @@ class Automation:
 
     @staticmethod
     def deploy_as_upload_data_feed(task, api_inputs: ApiInputs, expected_delivery: EXPECTED_DELIVERY,
-                                   queue_name: QUEUE_NAME = 'task',
+                                   queue_name: QUEUE_NAME = 'task', data_feed_name: str = None,
                                    data_feed_id: uuid.UUID = None):
         """Deploy the custom driver as a REST API end point Datafeed.
 
@@ -595,6 +607,9 @@ class Automation:
             The expected delivery frequency of the data.
         queue_name : QUEUE_NAME, optional
             The queue name (Default value = 'task').
+        data_feed_name : str, Optional
+            The name of the data feed (to be displayed in Task Insights UI). If not provided, will default to the
+            task name.
         data_feed_id : uuid.UUID, Optional
             The DataFeedId to update if existing, else will create a new record with the given value.
 
@@ -609,8 +624,12 @@ class Automation:
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        if data_feed_id is None:
+        if data_feed_id is None and data_feed_name is None:
             data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+            data_feed_name = task.__class__.__qualname__
+        elif data_feed_id is not None and data_feed_name is None:
+            data_feed_id = data_feed_id
+            data_feed_name = data_feed_name
 
         headers = api_inputs.api_headers.default
 
@@ -630,7 +649,7 @@ class Automation:
         payload = {
             "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
-            "name": 'Feed Settings for ' + type(task).__name__,
+            "name": data_feed_name,
             "feedType": ",".join(task.mapping_entities),
             "expectedDelivery": expected_delivery,
             "sourceType": "upload",
@@ -663,7 +682,7 @@ class Automation:
     def deploy_on_timer(task, api_inputs: ApiInputs, cron_schedule: str, expected_delivery: EXPECTED_DELIVERY,
                         queue_name: QUEUE_NAME = "task", settings: dict = None,
                         schedule_timezone: SCHEDULE_TIMEZONE = 'Local', timezone_offset_minutes: int = None,
-                        data_feed_id: uuid.UUID = None):
+                        data_feed_name: str = None, data_feed_id: uuid.UUID = None):
         """Deploy driver to run on timer.
 
         Parameters
@@ -687,6 +706,9 @@ class Automation:
             taken as the timezone of the western-most site in the given portfolio (Default value = 'Local').
         timezone_offset_minutes: int, Optional
             Timezone offset in minutes (from UTC) to be used when applying the ``cron_schedule`` (Default value = None).
+        data_feed_name : str, Optional
+            The name of the data feed (to be displayed in Task Insights UI). If not provided, will default to the
+            task name.
         data_feed_id : uuid.UUID, Optional
             The DataFeedId to update if existing, else will create a new record with the given value.
 
@@ -701,8 +723,12 @@ class Automation:
             logger.error("You must call initialize() before using API.")
             return pandas.DataFrame()
 
-        if data_feed_id is None:
+        if data_feed_id is None and data_feed_name is None:
             data_feed_id = uuid.UUID('00000000-0000-0000-0000-000000000000')
+            data_feed_name = task.__class__.__qualname__
+        elif data_feed_id is not None and data_feed_name is None:
+            data_feed_id = data_feed_id
+            data_feed_name = data_feed_name
 
         if timezone_offset_minutes is None:
             timezone_offset_minutes = 0
@@ -756,19 +782,6 @@ class Automation:
         #         if len(missing_required_keys) > 0 and len(missing_optional_keys) == 0:
         #             loggger.error(f"settings parameter is missing the following required key(s): {missing_required_keys}.")
 
-
-
-
-        # expected_deliveries = re.findall(r'[A-Za-z]+|\d+', expected_delivery)
-        # if len(expected_deliveries) != 2 or expected_deliveries[0].isnumeric() is not True:
-        #     logger.error("Run At parameter must take the form of a number followed by a time type. ")
-        #     return pandas.DataFrame()
-        #
-        # time_type = expected_deliveries[1].lower()[:3]
-        # if time_type != 'min' and time_type != 'hour' and time_type != 'day':
-        #     logger.error("The expected_delivery time type must start with one of: min, hour, day. ")
-        #     return pandas.DataFrame()
-
         logger.info('Deploy %s (%s) on timer for ApiProjectID: %s and schedule: %s.', type(task).__name__,
                     str(task.id), api_inputs.api_project_id, cron_schedule)
         logger.info('Feed Type is %s', str(task.mapping_entities))
@@ -777,7 +790,7 @@ class Automation:
         payload = {
             "dataFeedId": str(data_feed_id),
             "driverId": str(task.id),
-            "name": 'Timer Settings for ' + type(task).__name__,
+            "name": data_feed_name,
             "feedType": ",".join(task.mapping_entities),
             "expectedDelivery": expected_delivery,
             "sourceType": "Timer",
