@@ -218,11 +218,11 @@ class IntegrationTask(Task):
 class DiscoverableIntegrationTask(Task):
     """Discoverable Integration Task
 
-    This class is used to create integrations that post data to the Switch Automation platform.
+    This class is used to create integrations that post data to the Switch Automation platform from 3rd party APIs that
+    have discovery functionality.
 
-
-    The process() method should contain the code required to post data for the integration. The run_discovery() method
-    upserts records into the Integrations table so that end users can configure the points and import as
+    The `process()` method should contain the code required to post data for the integration. The `run_discovery()`
+    method upserts records into the Integrations table so that end users can configure the points and import as
     devices/sensors within the Build - Discovery and Selection UI in the Switch Automation platform.
 
     Additional properties are required to be created to support both the discovery functionality & the subsequent
@@ -233,10 +233,10 @@ class DiscoverableIntegrationTask(Task):
     @property
     @abstractmethod
     def integration_device_type_definition(self) -> IntegrationDeviceDefinition:
-        """The IntegrationDeviceDefinition used to create the DriverDevices records required for the Integration Device
-        to be available to drag & drop in the Build - Integration Schematic UI. Contains the properties that define the
-        minimum set of required fields to be passed to the integration_settings dictionaries for the process() and
-        run_discovery() methods"""
+        """The IntegrationDeviceDefinition used to create the DriverDevices records required for the Integration
+        DeviceType to be available to drag & drop in the Build - Integration Schematic UI. Contains the properties that
+        define the minimum set of required fields to be passed to the integration_settings dictionaries for the
+        `process()` and `run_discovery()` methods"""
         pass
 
     # @property
@@ -317,9 +317,7 @@ class EventWorkOrderTask(Task):
     def work_order_fields_definition(self) -> List[EventWorkOrderFieldDefinition]:
         """Define the fields available in Events UI when creating a work order in 3rd Party System.
 
-        The definition of the dictionary keys, display
-
-        The definition of the dictionary keys, display labels in Task Insights UI, default value & allowed values
+        The definition of the dictionary keys, display labels in Events UI, default value & allowed values
         for the generate_work_order() method's ``work_order_input`` parameter.
 
             property_name - the ``work_order_input`` dictionary key
@@ -335,11 +333,10 @@ class EventWorkOrderTask(Task):
     @property
     @abstractmethod
     def integration_settings_definition(self) -> List[IntegrationSettings]:
-        """
-        Define the generate_work_order() method's integration_settings dictionary requirements & defaults.
+        """Define the generate_work_order() method's integration_settings dictionary requirements & defaults.
 
         The definition of the dictionary keys, display labels in Task Insights UI, default value & allowed values
-        for the start() method's ``analytics_settings`` input parameter.
+        for the generate_work_order() method's ``integration_settings`` input parameter.
 
             property_name - the analytics_settings dictionary key
             display_label - the display label for the given property_name in Task Insights UI
